@@ -55,6 +55,7 @@ def upload_key():
 def create_superuser():
     Pipeline.createsuperuser()
 
+
 @main.command()
 def resetdb():
     Pipeline.reset_db()
@@ -77,11 +78,6 @@ def run(command):
     Pipeline.run_command(command=command)
 
 
-@main.command()
-def test():
-    Pipeline.test()
-
-
 @main.command()
 def check_language():
     Pipeline.server_language()
